/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import java.util.*;

/**
* This class is provides founctions of handling page navigated information
* and event listener class/object registration.
*/
public class PageController implements java.io.Serializable {
    String currentPage;
    String lastCommand;
    Hashtable table;
    ReuseData reuseData;
    String listenerClass;
    Object listenerObject;

    /**
    * Constructor.
    */
    public PageController() {
        table = new Hashtable();
        reuseData = new ReuseData();
    }

    /**
    * This method keeps requested parameter-value pair in the HTTP-request.
    * @param values     a PostedValues object
    */
    protected void setPostedValues(PostedValues values) {
        for (Enumeration enum = values.getParameterNames(); enum.hasMoreElements();) {
            String name = (String)enum.nextElement();
            String val = values.getParameter(name);
            reuseData.setValue(name, val);
        }
    }

    /**
    * Gets ReuseData object.
    * @return   a ReuseData object
    */
    public ReuseData getReuseData() {
        return reuseData;
    }

    /**
    * Sets ReuseData object.
    * @param reuseData      a ReuseData object
    */
    public void setReuseData(ReuseData reuseData) {
        this.reuseData = reuseData;
    }

    /**
    * Initialize reuse data, page navigeted information and event listener.
    */
    public void initAll() {
        reuseData = new ReuseData();
        initPage();
    }

    /**
    * Initialize page navigeted information and event listener.
    */
    public void initPage() {
        table.clear();
        listenerClass = null;
        listenerObject = null;
    }

    /**
    * Registers the page information.
    * @param id     the page ID
    * @param jsp    file name of JSP
    */
    public void putPage(String id, String jsp) {
        table.put(id, jsp);
    }

    /**
    * Retrieves the page information by ID.
    * @param id     the page ID
    * @return       file name of JSP
    */
    public String getPage(String id) {
        return (String)table.get(id);
    }

    protected void setCurrentPage(String page) {
        currentPage = page;
    }

    /**
    * Retrieves the current user navigated page information.
    * When the current page is the just after checked-out page, returns null.
    * @return       file name of JSP
    */
    public String getCurrentPage() {
        return currentPage;
    }

    protected void setLastCommand(String cmd) {
        lastCommand = cmd;
    }

    /**
    * Retrieves the last 'command' parameter in the HTTP-request.
    * @return       the last requested command string.
    */
    public String getLastCommand() {
        return lastCommand;
    }

    /**
    * Registers the event listner class.
    * @param className      the event listner class name
    */
    public void setEventListenerClassName(String className) {
        listenerClass = className;
    }

    /**
    * Retrieves the the event listner class.
    * @return   event listner class name
    */
    public String getEventListenerClassName() {
        return listenerClass;
    }

    /**
    * Registers the event listner object.
    * @param listener       the event listner object
    */
    public void setEventListenerObject(Object listener) {
        listenerObject = listener;
    }

    /**
    * Retrieves the the event listner object.
    * @return   an event listner object
    */
    public Object getEventListenerObject() {
        return listenerObject;
    }

    protected Object getEventListener() {
        if (listenerObject != null)
            return listenerObject;

        if (listenerClass == null)
            return null;

        try {
            Class cls = Class.forName(listenerClass);
            Object obj = cls.newInstance();
            return obj;
        } catch (Exception ex) {
            return null;
        }
    }

}
