/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import com.ibm.workflow.servlet.client.*;

/**
* An abstract adapter class for receiving page events.
*/
public abstract class PageEventListenerAdapter implements
                            CheckInWorkItemEventListener,
                            CancelWorkItemEventListener,
                            PageChangeEventListener,
                            java.io.Serializable {

    /**
    * Invoked when a work item just before check-in.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @param values     a PostedValues object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    public ResponsePage queryCheckInWorkItem(RequestContext context, PageController controller, PostedValues values) throws ClientException {
        return null;
    }

    /**
    * Invoked when a work item has been checked-in.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    public ResponsePage postCheckInWorkItem(RequestContext context, PageController controller) throws ClientException {
        return null;
    }

    /**
    * Invoked when a work item has been canceled.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    public ResponsePage postCancelWorkItem(RequestContext context, PageController controller) throws ClientException {
        return null;
    }

    /**
    * Invoked when a response page just before change.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    public ResponsePage queryPageChange(RequestContext context, PageController controller, PostedValues values) throws ClientException {
        return null;
    }
}
